@@ -1,3 +1,3 @@
-`c.a2.h` <-
+`C.a2.h` <-
 function (c)        ifelse(!(le(0,c) && le(c,1)),                                        NA, c)
 
