@@ -1,3 +1,3 @@
-`c.a2.l` <-
+`C.a2.l` <-
 function (c)                                                                                 1-pnorm(c)
 
